"use strict";

function log(...args) {
  const time = new Date().toISOString();
  console.log(`[${time}]`, ...args);
}

/* Activate eagerly as soon as the worker gets updated. Normally, when a worker
   is updated, the previous version still gets to control new pages until all
   of its controlled pages are closed simultaneously. We skip this, so new
   pages will get the latest shoutbox service worker as soon as possible. */
self.addEventListener("install", (e) => {
  log("installing!");
  /* This promise is guarantee OK to ignore by API */
  self.skipWaiting();
});

/* As soon as the worker activates, we claim existing clients. This means that
   not only new pages will use the updated worker, but running ones will also
   transition to it, giving us transparent background updates. We handle
   protocol differences manually; if the main script cannot handle the new
   shoutbox version it will simply ask for a reload. Doing this allows us to
   take control of the shoutbox without a page refresh when it is loaded for
   the first time. */
self.addEventListener("activate", (e) => {
  log("activating!");
  e.waitUntil(self.clients.claim());
});

self.addEventListener("message", (e) => {
  log(e);
  if(e.data[0] == "!") {
    log("responding");
    e.source.postMessage(e.data.substring(1));
  }
});
